@@ -21,94 +21,98 @@ use crate::prelude::Txn;
 pub mod mutations_helpers;
 
 /// Create a [TestEnv] of [`DbKindAuthored`], backed by a temp directory.
-pub fn test_authored_env() -> TestEnv<DbKindAuthored> {
-    test_authored_env_with_id(1)
+pub fn test_authored_db() -> TestDb<DbKindAuthored> {
+    test_authored_db_with_id(1)
 }
 
-pub fn test_authored_env_with_id(id: u8) -> TestEnv<DbKindAuthored> {
-    test_env(DbKindAuthored(Arc::new(fake_dna_hash(id))))
+pub fn test_authored_db_with_id(id: u8) -> TestDb<DbKindAuthored> {
+    test_db(DbKindAuthored(Arc::new(fake_dna_hash(id))))
 }
 
-pub fn test_authored_env_with_dna_hash(hash: DnaHash) -> TestEnv<DbKindAuthored> {
-    test_env(DbKindAuthored(Arc::new(hash)))
+pub fn test_authored_db_with_dna_hash(hash: DnaHash) -> TestDb<DbKindAuthored> {
+    test_db(DbKindAuthored(Arc::new(hash)))
 }
 
 /// Create a [TestEnv] of [`DbKindDht`], backed by a temp directory.
-pub fn test_dht_env() -> TestEnv<DbKindDht> {
-    test_dht_env_with_id(1)
+pub fn test_dht_db() -> TestDb<DbKindDht> {
+    test_dht_db_with_id(1)
 }
 
-pub fn test_dht_env_with_id(id: u8) -> TestEnv<DbKindDht> {
-    test_env(DbKindDht(Arc::new(fake_dna_hash(id))))
+pub fn test_dht_db_with_id(id: u8) -> TestDb<DbKindDht> {
+    test_db(DbKindDht(Arc::new(fake_dna_hash(id))))
 }
 
-pub fn test_dht_env_with_dna_hash(hash: DnaHash) -> TestEnv<DbKindDht> {
-    test_env(DbKindDht(Arc::new(hash)))
+pub fn test_dht_db_with_dna_hash(hash: DnaHash) -> TestDb<DbKindDht> {
+    test_db(DbKindDht(Arc::new(hash)))
 }
 
 /// Create a [TestEnv] of [`DbKindCache`], backed by a temp directory.
-pub fn test_cache_env() -> TestEnv<DbKindCache> {
-    test_cache_env_with_id(1)
+pub fn test_cache_db() -> TestDb<DbKindCache> {
+    test_cache_db_with_id(1)
 }
 
-pub fn test_cache_env_with_id(id: u8) -> TestEnv<DbKindCache> {
-    test_env(DbKindCache(Arc::new(fake_cell_id(id).dna_hash().clone())))
+pub fn test_cache_db_with_id(id: u8) -> TestDb<DbKindCache> {
+    test_db(DbKindCache(Arc::new(fake_cell_id(id).dna_hash().clone())))
 }
 
-pub fn test_cache_env_with_dna_hash(hash: DnaHash) -> TestEnv<DbKindCache> {
-    test_env(DbKindCache(Arc::new(hash)))
+pub fn test_cache_db_with_dna_hash(hash: DnaHash) -> TestDb<DbKindCache> {
+    test_db(DbKindCache(Arc::new(hash)))
 }
 
 /// Create a [TestEnv] of [DbKindConductor], backed by a temp directory.
-pub fn test_conductor_env() -> TestEnv<DbKindConductor> {
-    test_env(DbKindConductor)
+pub fn test_conductor_db() -> TestDb<DbKindConductor> {
+    test_db(DbKindConductor)
 }
 
 /// Create a [TestEnv] of [DbKindWasm], backed by a temp directory.
-pub fn test_wasm_env() -> TestEnv<DbKindWasm> {
-    test_env(DbKindWasm)
+pub fn test_wasm_db() -> TestDb<DbKindWasm> {
+    test_db(DbKindWasm)
 }
 
 /// Create a [TestEnv] of [DbKindP2pAgentStore], backed by a temp directory.
-pub fn test_p2p_agent_store_env() -> TestEnv<DbKindP2pAgentStore> {
-    test_env(DbKindP2pAgentStore(Arc::new(KitsuneSpace(vec![0; 36]))))
+pub fn test_p2p_agents_db() -> TestDb<DbKindP2pAgents> {
+    test_db(DbKindP2pAgents(Arc::new(KitsuneSpace(vec![0; 36]))))
 }
 
 /// Create a [TestEnv] of [DbKindP2pMetrics], backed by a temp directory.
-pub fn test_p2p_metrics_env() -> TestEnv<DbKindP2pMetrics> {
-    test_env(DbKindP2pMetrics(Arc::new(KitsuneSpace(vec![0; 36]))))
+pub fn test_p2p_metrics_db() -> TestDb<DbKindP2pMetrics> {
+    test_db(DbKindP2pMetrics(Arc::new(KitsuneSpace(vec![0; 36]))))
 }
 
-fn test_env<Kind: DbKindT>(kind: Kind) -> TestEnv<Kind> {
+fn test_db<Kind: DbKindT>(kind: Kind) -> TestDb<Kind> {
     let tmpdir = tempfile::Builder::new()
-        .prefix("holochain-test-environments")
+        .prefix("holochain-test-environments-")
         .suffix(&nanoid::nanoid!())
         .tempdir()
         .unwrap();
-    TestEnv {
-        env: DbWrite::test(&tmpdir, kind).expect("Couldn't create test database"),
+    TestDb {
+        db: DbWrite::test(tmpdir.path(), kind).expect("Couldn't create test database"),
         tmpdir,
     }
 }
 
-/// Create a fresh set of test environments with a new TempDir and custom MetaLairClient
-pub fn test_envs_with_keystore(keystore: MetaLairClient) -> TestEnvs {
-    let tempdir = tempfile::Builder::new()
-        .prefix("holochain-test-environments")
-        .suffix(&nanoid::nanoid!())
-        .tempdir()
-        .unwrap();
-    TestEnvs::with_keystore(tempdir, keystore)
+/// Create a [`DbWrite`] of [`DbKindT`] in memory.
+pub fn test_in_mem_db<Kind: DbKindT>(kind: Kind) -> DbWrite<Kind> {
+    DbWrite::test_in_mem(kind).expect("Couldn't create test database")
 }
 
 /// Create a fresh set of test environments with a new TempDir
-pub fn test_environments() -> TestEnvs {
-    let tempdir = tempfile::Builder::new()
+pub fn test_db_dir() -> TempDir {
+    tempfile::Builder::new()
         .prefix("holochain-test-environments")
         .suffix(&nanoid::nanoid!())
         .tempdir()
+        .unwrap()
+}
+
+/// Create a fresh set of test environments with a new TempDir in a given directory.
+pub fn test_dbs_in(path: impl AsRef<Path>) -> TestDbs {
+    let tempdir = tempfile::Builder::new()
+        .prefix("holochain-test-environments")
+        .suffix(&nanoid::nanoid!())
+        .tempdir_in(path)
         .unwrap();
-    TestEnvs::new(tempdir)
+    TestDbs::new(tempdir)
 }
 
 /// Generate a test keystore pre-populated with a couple test keypairs.
@@ -128,18 +132,18 @@ pub fn test_keystore() -> holochain_keystore::MetaLairClient {
 
 /// A test database in a temp directory
 #[derive(Shrinkwrap)]
-pub struct TestEnv<Kind: DbKindT> {
+pub struct TestDb<Kind: DbKindT> {
     #[shrinkwrap(main_field)]
     /// sqlite database
-    env: DbWrite<Kind>,
+    db: DbWrite<Kind>,
     /// temp directory for this environment
     tmpdir: TempDir,
 }
 
-impl<Kind: DbKindT> TestEnv<Kind> {
+impl<Kind: DbKindT> TestDb<Kind> {
     /// Accessor
-    pub fn env(&self) -> DbWrite<Kind> {
-        self.env.clone()
+    pub fn to_db(&self) -> DbWrite<Kind> {
+        self.db.clone()
     }
 
     /// Accessor
@@ -167,30 +171,17 @@ impl<Kind: DbKindT> TestEnv<Kind> {
 
     /// Dump db into `/tmp/test_dbs`.
     pub fn dump_tmp(&self) {
-        dump_tmp(&self.env);
+        dump_tmp(&self.db);
     }
 
     pub fn dna_hash(&self) -> Option<Arc<DnaHash>> {
-        match self.env.kind().kind() {
+        match self.db.kind().kind() {
             DbKind::Authored(hash) | DbKind::Cache(hash) | DbKind::Dht(hash) => Some(hash),
             _ => None,
         }
     }
 }
-// /// Dump db into `/tmp/test_dbs`.
-// pub fn dump_tmp(env: &DbWrite) {
-//     let mut tmp = std::env::temp_dir();
-//     tmp.push("test_dbs");
-//     std::fs::create_dir(&tmp).ok();
-//     tmp.push("backup.sqlite");
-//     std::fs::write(&tmp, b"").unwrap();
-//     env.conn()
-//         .unwrap()
-//         .transaction_with_behavior(holochain_sqlite::rusqlite::TransactionBehavior::Exclusive)
-//         .unwrap()
-//         .backup(DatabaseName::Main, tmp, None)
-//         .unwrap();
-// }
+
 /// Dump db into `/tmp/test_dbs`.
 pub fn dump_tmp<Kind: DbKindT>(env: &DbWrite<Kind>) {
     let mut tmp = std::env::temp_dir();
@@ -207,13 +198,13 @@ pub fn dump_tmp<Kind: DbKindT>(env: &DbWrite<Kind>) {
 }
 
 /// A container for all three non-cell environments
-pub struct TestEnvs {
+pub struct TestDbs {
     /// A test conductor environment
     conductor: DbWrite<DbKindConductor>,
     /// A test wasm environment
     wasm: DbWrite<DbKindWasm>,
     /// A test p2p environment
-    p2p: Arc<parking_lot::Mutex<HashMap<Arc<KitsuneSpace>, DbWrite<DbKindP2pAgentStore>>>>,
+    p2p: Arc<parking_lot::Mutex<HashMap<Arc<KitsuneSpace>, DbWrite<DbKindP2pAgents>>>>,
     /// A test p2p environment
     p2p_metrics: Arc<parking_lot::Mutex<HashMap<Arc<KitsuneSpace>, DbWrite<DbKindP2pMetrics>>>>,
     /// The shared root temp dir for these environments
@@ -223,11 +214,11 @@ pub struct TestEnvs {
 }
 
 #[allow(missing_docs)]
-impl TestEnvs {
+impl TestDbs {
     /// Create all three non-cell environments at once with a custom keystore
     pub fn with_keystore(tempdir: TempDir, keystore: MetaLairClient) -> Self {
-        let conductor = DbWrite::test(&tempdir, DbKindConductor).unwrap();
-        let wasm = DbWrite::test(&tempdir, DbKindWasm).unwrap();
+        let conductor = DbWrite::test(tempdir.path(), DbKindConductor).unwrap();
+        let wasm = DbWrite::test(tempdir.path(), DbKindWasm).unwrap();
         let p2p = Arc::new(parking_lot::Mutex::new(HashMap::new()));
         let p2p_metrics = Arc::new(parking_lot::Mutex::new(HashMap::new()));
         Self {
@@ -255,7 +246,7 @@ impl TestEnvs {
 
     pub fn p2p(
         &self,
-    ) -> Arc<parking_lot::Mutex<HashMap<Arc<KitsuneSpace>, DbWrite<DbKindP2pAgentStore>>>> {
+    ) -> Arc<parking_lot::Mutex<HashMap<Arc<KitsuneSpace>, DbWrite<DbKindP2pAgents>>>> {
         self.p2p.clone()
     }
 
